Software support
~~~~~~~~~~~~~~~~

* We announce major and minor package updates via twitter.  Follow the hashtag `#pybliometrics <https://twitter.com/hashtag/pybliometrics>`_ to be the first to learn of software updates.
* The best place to ask questions on how to do things is StackOverflow.  Simply tag your question with `pybliometrics <https://stackoverflow.com/questions/tagged/pybliometrics>`_.
* In the GitHub repository, you can create issues and report bugs, requests featurs, or, even better, submit pull requests on your own.  Read more about contributing :doc:`here <../contributing>`.
